// java wrapper for vtkImageReader2Collection object
//

package vtk;
import vtk.*;

public class vtkImageReader2Collection extends vtkCollection
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void AddItem_2(vtkImageReader2 id0);
  public void AddItem(vtkImageReader2 id0)
    { AddItem_2(id0); }

  private native long GetNextItem_3();
  public vtkImageReader2 GetNextItem() {
    long temp = GetNextItem_3();

    if (temp == 0) return null;
    return (vtkImageReader2)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  public vtkImageReader2Collection() { super(); }

  public vtkImageReader2Collection(long id) { super(id); }
  public native long   VTKInit();

}
